AgentThreadStorageRepository class

Inheritance

Constructors

AgentThreadStorageRepository({required BaseChatClient chatClient, int limit = 200})

Properties

chatClient BaseChatClient
final
hashCode int
The hash code for this object.
no setterinherited
limit int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener()) → void
inherited
addOrUpdateThread(ThreadListEntry entry) Future<void>
override
close() Future<void>
override
deleteThread(String threadPath) Future<void>
override
entries() List<ThreadListEntry>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
open() Future<void>
override
removeListener(void listener()) → void
inherited
renameThread(String threadPath, String name) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited