ThreadCleared class
- Inheritance
-
- Object
- AgentMessage
- AgentThreadMessage
- ThreadCleared
Constructors
- ThreadCleared({required String threadId, required String sourceMessageId, String? messageId, String? senderName})
-
ThreadCleared.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAtUtc → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → String
-
finalinherited
-
metadata
→ Map<
String, dynamic> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderName → String?
-
Optional display name for the sender.
finalinherited
- sourceMessageId → String
-
final
- threadId → String
-
finalinherited
- type → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited