AgentImageGenerationCompleted class
- Inheritance
-
- Object
- AgentMessage
- AgentThreadMessage
- AgentLLMMessage
- AgentImageGenerationCompleted
Constructors
-
AgentImageGenerationCompleted({required String threadId, required String turnId, required String itemId, String? messageId, String? senderName, String? provider, String? model, String? callId, String toolkit = 'image_generation', String tool = 'image_generation', Map<
String, dynamic> ? arguments, List<AgentGeneratedImage> images = const <AgentGeneratedImage>[]}) -
AgentImageGenerationCompleted.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
arguments
→ Map<
String, dynamic> ? -
finalinherited
- backend → String?
-
finalinherited
- callId → String?
-
finalinherited
- createdAtUtc → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
images
→ List<
AgentGeneratedImage> -
final
- itemId → String
-
finalinherited
- messageId → String
-
finalinherited
-
metadata
→ Map<
String, dynamic> -
no setterinherited
- model → String?
-
finalinherited
- provider → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderName → String?
-
Optional display name for the sender.
finalinherited
- threadId → String
-
finalinherited
- tool → String
-
finalinherited
- toolkit → String
-
finalinherited
- turnId → String
-
finalinherited
- type → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited