AgentToolCallInProgress class
- Inheritance
-
- Object
- AgentMessage
- AgentThreadMessage
- AgentLLMMessage
- AgentToolCallPending
- AgentToolCallInProgress
Constructors
-
AgentToolCallInProgress({required String threadId, required String turnId, required String itemId, required String toolkit, required String tool, String? messageId, String? senderName, String? provider, String? model, String namespace = 'meshagent', String? callId, Map<
String, dynamic> ? arguments, int? argumentBytes}) -
AgentToolCallInProgress.fromJson(Map<
String, dynamic> json) -
factory
Properties
- argumentBytes → int?
-
finalinherited
-
arguments
→ Map<
String, dynamic> ? -
finalinherited
- backend → String?
-
finalinherited
- callId → String?
-
finalinherited
- createdAtUtc → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemId → String
-
finalinherited
- messageId → String
-
finalinherited
-
metadata
→ Map<
String, dynamic> -
no setterinherited
- model → String?
-
finalinherited
- namespace → String
-
finalinherited
- provider → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderName → String?
-
Optional display name for the sender.
finalinherited
- threadId → String
-
finalinherited
- tool → String
-
finalinherited
- toolkit → String
-
finalinherited
- turnId → String
-
finalinherited
- type → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited