ThreadStorageRepository class abstract
- Inheritance
-
- Object
- ChangeEmitter
- ThreadStorageRepository
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
void listener()) → void -
inherited
-
addOrUpdateThread(
ThreadListEntry entry) → Future< void> -
close(
) → Future< void> -
deleteThread(
String threadPath) → Future< void> -
entries(
) → List< ThreadListEntry> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
inherited
-
open(
) → Future< void> -
removeListener(
void listener()) → void -
inherited
-
renameThread(
String threadPath, String name) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited